@@ -1,7 +1,7 @@
 # Copyright (c) The Diem Core Contributors
 # SPDX-License-Identifier: Apache-2.0
 
-"""Python client sdk library for the [Diem](https://libra.org) blockchain network."""
+"""Python client SDK library for the [Diem](https://diem.com) blockchain network."""
 
 from .utils import InvalidAccountAddressError, InvalidSubAddressError
 from .auth_key import AuthKey
