@@ -3,8 +3,6 @@
 
 import typing, dataclasses, uuid
 
-from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey
-from cryptography.exceptions import InvalidSignature
 from .types import (
     CommandRequestObject,
     ErrorCode,
@@ -121,6 +119,7 @@ class PaymentCommand(Command):
         abort_code: typing.Optional[str] = None,
         abort_message: typing.Optional[str] = None,
         inbound: bool = False,
+        metadata: typing.Optional[typing.List[str]] = None,
     ) -> Command:
         changes: typing.Dict[str, typing.Any] = {
             self.my_actor().value: replace_payment_actor(
@@ -130,6 +129,7 @@ class PaymentCommand(Command):
                 additional_kyc_data=additional_kyc_data,
                 abort_code=abort_code,
                 abort_message=abort_message,
+                metadata=metadata,
             ),
         }
         if recipient_signature:
