@@ -4,7 +4,7 @@
 """Utilities for data type converting, construction and hashing."""
 
 from cryptography.hazmat.primitives import serialization
-from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey
+from cryptography.hazmat.primitives.asymmetric.ed25519 import Ed25519PublicKey, Ed25519PrivateKey
 import hashlib
 import typing
 
@@ -79,11 +79,21 @@ def sub_address(addr: typing.Union[str, bytes]) -> bytes:
 
 
 def public_key_bytes(public_key: Ed25519PublicKey) -> bytes:
-    """convert cryptography.hazmat.primitives.asymmetric.ed25519.Ed25519PublicKey into bytes"""
+    """convert cryptography.hazmat.primitives.asymmetric.ed25519.Ed25519PublicKey into raw bytes"""
 
     return public_key.public_bytes(encoding=serialization.Encoding.Raw, format=serialization.PublicFormat.Raw)
 
 
+def private_key_bytes(private_key: Ed25519PrivateKey) -> bytes:
+    """convert cryptography.hazmat.primitives.asymmetric.ed25519.Ed25519PrivateKey into raw bytes"""
+
+    return private_key.private_bytes(
+        encoding=serialization.Encoding.Raw,
+        format=serialization.PrivateFormat.Raw,
+        encryption_algorithm=serialization.NoEncryption(),
+    )
+
+
 def currency_code(code: str) -> diem_types.TypeTag:
     """converts currency code string to diem_types.TypeTag"""
 
@@ -110,7 +120,7 @@ def create_signed_transaction(
 def raw_transaction_signing_msg(txn: diem_types.RawTransaction) -> bytes:
     """create signing message from given `diem_types.RawTransaction`"""
 
-    return diem_hash_seed(b"RawTransaction") + txn.lcs_serialize()
+    return diem_hash_seed(b"RawTransaction") + txn.bcs_serialize()
 
 
 def transaction_hash(txn: diem_types.SignedTransaction) -> str:
@@ -120,7 +130,7 @@ def transaction_hash(txn: diem_types.SignedTransaction) -> str:
     """
 
     user_txn = diem_types.Transaction__UserTransaction(value=txn)
-    return hash(diem_hash_seed(b"Transaction"), user_txn.lcs_serialize()).hex()
+    return hash(diem_hash_seed(b"Transaction"), user_txn.bcs_serialize()).hex()
 
 
 def diem_hash_seed(typ: bytes) -> bytes:
@@ -147,7 +157,7 @@ def decode_transaction_script(
     """
 
     if isinstance(txn, str):
-        script = diem_types.Script.lcs_deserialize(bytes.fromhex(txn))
+        script = diem_types.Script.bcs_deserialize(bytes.fromhex(txn))
         return stdlib.decode_script(script)
     if isinstance(txn, jsonrpc.Transaction):
         return decode_transaction_script(txn.transaction.script_bytes)
